Welcome to ClientVPS Mirrors

Help for package snem
Type: Package
Title: EM Algorithm for Multivariate Skew-Normal Distribution with Overparametrization
Version: 0.1.1
Date: 2020-03-02
Author: Toshihiro Abe <abetosh@ss.nanzan-u.ac.jp>, Hironori Fujisawa <fujisawa@ism.ac.jp>, Takayuki Kawashima <kawashima@c.titech.ac.jp>
Maintainer: Takayuki Kawashima <kawashima@c.titech.ac.jp>
Imports: mvtnorm
Description: Efficient estimation of multivariate skew-normal distribution in closed form.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
LazyData: true
Suggests: sn
RoxygenNote: 7.0.2
NeedsCompilation: no
Packaged: 2020-03-02 13:13:36 UTC; takayukikawashima
Repository: CRAN
Date/Publication: 2020-03-16 12:30:02 UTC

EM algorithm for multivariate skew normal distribution.

Description

EM algorithm in closed form.

Usage

snem(
  x,
  eps = 0.9,
  iter.eps = 10^-6,
  stop.rule = c("parameter", "log-likelihood")
)

Arguments

x

A data matrix. Each row is an observation vector.

eps

Weight parameter with 0 \le eps < 1. Default is 0.9.

iter.eps

Convergence threshold. Default is 10^-6.

stop.rule

"parameter": The difference of the parameter is used as a stopping rule. "log-likelihood" The difference of the log-likelihood is used as a stopping rule.

Details

The parameter eps is a tuning parameter which ensures that an initial covariance matrix is positive semi-definite.

Value

Location parameter (mu), covariance matrix (omega), skewness parameter (delta), and another expression of skewness parameter (lambda).

References

Abe, T., Fujisawa, H., and Kawashima, T. (2019) EM algorithm using overparametrization for multivariate skew-normal distribution, in preparation.

Examples

library(sn)
data(ais, package="sn")
x <- ais[c("BMI")]
snem(x, stop.rule ="log-likelihood")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.